@@ -57,6 +57,10 @@ private slots:
 
     void on_actionRigth_2_triggered();
 
+    void on_btnMenu_pressed();
+
+    void on_actionNew_Game_triggered();
+
 private:
     Ui::MainWindow *ui;
 
@@ -72,6 +76,7 @@ private:
     int destinationColor;// = random.randint(0,2);
 
     int currentLevel;
+    int numberOfLevels;
 
     int moves;
     int playerCurrentX;
@@ -80,7 +85,7 @@ private:
     QLabel *currentImages[16][16];
     int currentContent[16][16];
     int resetContent[16][16];
-    int levels[10][16][16];
+    int levels[15][16][16];
 };
 
 #endif // MAINWINDOW_H
